<?php

if ( !class_exists('woocommerce') ) return;



/*
	Activate woocommerce support
	----------------------------
*/
add_action('after_setup_theme', function () {
	add_theme_support('woocommerce');
	add_theme_support('wc-product-gallery-zoom');
	add_theme_support('wc-product-gallery-lightbox');
	add_theme_support('wc-product-gallery-slider');
});



/*
	Remove default WooCommerce CSS
	----------------------------
*/
add_filter('woocommerce_enqueue_styles', function ( $enqueue_styles ) {
	unset( $enqueue_styles['woocommerce-layout'] );
	unset( $enqueue_styles['woocommerce-smallscreen'] );
	unset( $enqueue_styles['woocommerce-general'] );
	return $enqueue_styles;
});



/*
	Enqueue custom CSS for Woocommerce
	----------------------------
*/
add_action('wp_enqueue_scripts', function () {
	wp_enqueue_style( 'ghost-layout-css', get_template_directory_uri() . '/woocommerce/css/woo-layout.css' );
	wp_enqueue_style( 'ghost-smallscreen-css', get_template_directory_uri() . '/woocommerce/css/woo-smallscreen.css' );
	wp_enqueue_style( 'ghost-woocommerce-css', get_template_directory_uri() . '/woocommerce/css/woocommerce.css' );
});



/*
	Update cart in menu
	----------------------------
*/
add_filter('woocommerce_add_to_cart_fragments', function ( $fragments ) {
	ob_start(); ?>
	<a
		class="cart-contents"
		href="<?php echo esc_url(wc_get_cart_url()); ?>"
		title="<?php esc_attr_e( 'View your shopping cart', 'ghost-lite' ); ?>"
	>
		<span class="cart__icon__wrapper"><span class="cart__counter"><?php echo esc_html(WC()->cart->cart_contents_count); ?></span><span class="vissage-icon vissage-shopping-cart"></span></span>
		<span class="cart__total__items"><?php echo sprintf (_n( '%d item', '%d items', esc_html(WC()->cart->cart_contents_count), 'ghost-lite' ), esc_html(WC()->cart->cart_contents_count) ); ?> - <?php echo WC()->cart->get_cart_total(); ?></span>
	</a> 
	<?php $fragments['a.cart-contents'] = ob_get_clean();
	
	return $fragments;
});



/*
	Add cart to menu
	----------------------------
*/
add_filter('wp_nav_menu_items', function( $items, $args ) {
	if ( $args->theme_location == 'ghost-lite-main-menu' ) {
		$items .=	'<li class="menu-item nav-cart">';
		$items .=		'<a class="cart-contents" href="' . esc_url(wc_get_cart_url()) . '" title="' . esc_html__( 'View your shopping cart', 'ghost-lite' ) . '">';
		$items .=			'<span class="cart__icon__wrapper"><span class="cart__counter">'. esc_html(WC()->cart->cart_contents_count) .'</span><span class="vissage-icon vissage-shopping-cart"></span></span>';
		$items .=			'<span class="cart__total__items">' . sprintf (_n( '%d item', '%d items', esc_html(WC()->cart->cart_contents_count), 'ghost-lite' ), esc_html(WC()->cart->cart_contents_count) ) .' - '. WC()->cart->get_cart_total() . '</span>';
		$items .=		'</a>';
		$items .=	'</li>';
	}
	return $items;
}, 10, 2);



/*
	Remove titles
	----------------------------
*/
// remove single page title
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_title', 5);
// remove archive page titles
add_filter('woocommerce_show_page_title', function() {
	return false;
});



/*
	Add wrapper to sorting container
	----------------------------
*/
add_action('woocommerce_before_shop_loop', function() {
	echo '<div class="sorting__container flx">';
}, 15);
add_action('woocommerce_before_shop_loop', function() {
	echo '</div>';
}, 35);



/*
	Edit product loop item layout
	----------------------------
*/
remove_action('woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5);
add_action('woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_link_close', 15);

remove_action( 'woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10 );
add_action( 'woocommerce_shop_loop_item_title', function () {
	the_title( '<h2 class="woocommerce-loop-product__title"><a href="'. esc_url(get_the_permalink()) .'">', '</a></h2>' );
}, 10 );



/*
	Change related and up-sell products count
	----------------------------
*/
// related
add_filter('woocommerce_output_related_products_args', function ( $args ) {
	$args['posts_per_page'] = 3;
	$args['columns'] = 3;
	return $args;
}, 9999);
// up-sell
add_filter('woocommerce_upsell_display_args', function ( $args ) {
	$args['posts_per_page'] = 3;
	$args['columns'] = 3;
	return $args;
}, 20);



/*
	Change the breadcrumb separator
	----------------------------
*/
add_filter('woocommerce_breadcrumb_defaults', function ( $defaults ) {
	$defaults['delimiter'] = '<span class="vissage-icon vissage-angle-right"></span>';
	return $defaults;
});



/*
	Remove cropping from woo gallery thumbs
	----------------------------
*/
add_filter('woocommerce_get_image_size_gallery_thumbnail', function( $size ) {
	return array(
		'width' => 165,
		'height' => 200,
		'crop' => 0,
	);
});



/*
	Add "product/s" to cat count
	----------------------------
*/
remove_action('woocommerce_shop_loop_subcategory_title', 'woocommerce_template_loop_category_title', 10);
add_action('woocommerce_shop_loop_subcategory_title', function( $category ) {
	echo '<h2 class="woocommerce-loop-category__title">' . esc_html( $category->name ) . '</h2>';

	if ( $category->count > 0 ) echo ' <span class="count">' . esc_html( $category->count ) . ' ' . _nx( 'product', 'products', $category->count, 'product count', 'ghost-lite' ) .'</span>';
}, 10);

